subscriber

package
v0.0.0-...-fa17879 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2018 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Overview

Package subscriber holds the bits and bobs that listen to the pricing messages being firehosed onto the queue and does stuff to these messages... like... stores them and creates stats and stuff.

Index

Constants

const (
	THE_FORGE   = 10000002
	JITA        = 30000142 //60003760
	DOMAIN_R    = 10000043
	AMARR       = 30002187 //60008494
	HEIMATER    = 10000030
	RENS        = 30002510 //60004588
	SINQ_LAISON = 10000032
	DODIXIE     = 30002659 //60011866
)

Variables

Functions

This section is empty.

Types

type OrderSubImpl

type OrderSubImpl struct {
	// contains filtered or unexported fields
}

func NewOrderSubscriber

func NewOrderSubscriber(sess *mgo.Session) *OrderSubImpl

func (*OrderSubImpl) Init

func (sub *OrderSubImpl) Init()

func (*OrderSubImpl) Stats

func (sub *OrderSubImpl) Stats(regionId, typeId int32) *model.TypeStat

func (*OrderSubImpl) Subscribe

func (sub *OrderSubImpl) Subscribe(regionId int32)

Subscribe puts a new Handler function on the broker's subscription whatever. This function will produce 4 such Handler's:

  1. regionId.state.begin listener
  2. buy.regionId listener
  3. sell.regionId listener
  4. regionId.state.end listener

type OrderSubscriber

type OrderSubscriber interface {
	Subscribe(regionId int32)
	Init()
}

Jump to