Documentation
¶
Overview ¶
Package subscriber holds the bits and bobs that listen to the pricing messages being firehosed onto the queue and does stuff to these messages... like... stores them and creates stats and stuff.
Index ¶
Constants ¶
const ( THE_FORGE = 10000002 JITA = 30000142 //60003760 DOMAIN_R = 10000043 AMARR = 30002187 //60008494 HEIMATER = 10000030 RENS = 30002510 //60004588 SINQ_LAISON = 10000032 DODIXIE = 30002659 //60011866 )
Variables ¶
Functions ¶
This section is empty.
Types ¶
type OrderSubImpl ¶
type OrderSubImpl struct {
// contains filtered or unexported fields
}
func NewOrderSubscriber ¶
func NewOrderSubscriber(sess *mgo.Session) *OrderSubImpl
func (*OrderSubImpl) Init ¶
func (sub *OrderSubImpl) Init()
func (*OrderSubImpl) Subscribe ¶
func (sub *OrderSubImpl) Subscribe(regionId int32)
Subscribe puts a new Handler function on the broker's subscription whatever. This function will produce 4 such Handler's:
- regionId.state.begin listener
- buy.regionId listener
- sell.regionId listener
- regionId.state.end listener
type OrderSubscriber ¶
type OrderSubscriber interface {
Subscribe(regionId int32)
Init()
}
Click to show internal directories.
Click to hide internal directories.